@@ -57,7 +57,7 @@ nlmixr2CheckInstall <- function() {
   }
   pkgNames <-
     list(
-      rxode2 = c("rxode2", "rxode2et", "rxode2parse", "rxode2ll", "rxode2random", "lotri"),
+      rxode2 = c("rxode2", "rxode2ll", "lotri"),
       nlmixr2 = c("nlmixr2", "nlmixr2est", "nlmixr2data", "nlmixr2extra", "nlmixr2plot"),
       optional = c("nlmixr2lib", "nonmem2rx", "babelmixr2")
     )
